import { EventEmitter, Component, Output, Input, NgModule } from '@angular/core';
import zxcvbn from 'zxcvbn';

class StrengthMeterComponent {
    constructor() {
        this.measure = new EventEmitter();
    }
    set value(value) {
        if (value) {
            const result = zxcvbn(value);
            this.strength = result.score;
            this.measure.emit(this.strength);
        }
        else {
            this.strength = undefined;
        }
    }
}
StrengthMeterComponent.decorators = [
    { type: Component, args: [{
                template: `
    <div class="strength-meter">
      <div class="strength-meter-fill" [attr.data-strength]="strength"></div>
    </div>
  `,
                selector: 'strength-meter',
                styles: [`
      .strength-meter {
        position: relative;
        height: 3px;
        background: #DDD;
        margin: 10px auto 20px;
        border-radius: 3px;
      }

      .strength-meter:before,
      .strength-meter:after {
        content: '';
        height: inherit;
        background: transparent;
        display: block;
        border-color: #FFF;
        border-style: solid;
        border-width: 0 5px 0 5px;
        position: absolute;
        width: 80px;
        z-index: 10;
      }

      .strength-meter:before {
        left: 70px;
      }

      .strength-meter:after {
        right: 70px;
      }

      .strength-meter-fill {
        background: transparent;
        height: inherit;
        position: absolute;
        width: 0;
        border-radius: inherit;
        transition: width 0.5s ease-in-out, background 0.25s;
        -webkit-transition: width 0.5s ease-in-out, background 0.25s;
      }

      .strength-meter-fill[data-strength='0'] {
        background: darkred;
        width: 20%;
      }

      .strength-meter-fill[data-strength='1'] {
        background: orangered;
        width: 40%;
      }

      .strength-meter-fill[data-strength='2'] {
        background: orange;
        width: 60%;
      }

      .strength-meter-fill[data-strength='3'] {
        background: yellowgreen;
        width: 80%;
      }

      .strength-meter-fill[data-strength='4'] {
        background: green;
        width: 100%;
      }
    `]
            },] }
];
StrengthMeterComponent.propDecorators = {
    measure: [{ type: Output }],
    value: [{ type: Input }]
};

const COMPONENTS = [StrengthMeterComponent];
class StrengthMeterModule {
}
StrengthMeterModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: COMPONENTS,
                exports: COMPONENTS
            },] }
];

/**
 * Copyright Eisberg Labs
 * MIT license
 * https://github.com/eisberg-labs/ngx-strength-meter
 *
 * Entry point for all public APIs of the package.
 */

/**
 * Generated bundle index. Do not edit.
 */

export { StrengthMeterComponent, StrengthMeterModule };
//# sourceMappingURL=ngx-strength-meter.js.map
